### Name: facet_grid
### Title: facet_grid
### Aliases: facet_grid FacetGrid
### Keywords: hplot

### ** Examples
## Not run: 
##D # faceting displays subsets of the data in different panels
##D p <- ggplot(diamonds, aes(carat, ..density..)) +
##D  geom_histogram(binwidth = 0.2)
##D 
##D # With one variable
##D p + facet_grid(. ~ cut)
##D p + facet_grid(cut ~ .)
##D 
##D # With two variables
##D p + facet_grid(clarity ~ cut)
##D p + facet_grid(cut ~ clarity)
##D p + facet_grid(cut ~ clarity, margins=TRUE)
##D 
##D qplot(mpg, wt, data=mtcars, facets = . ~ vs + am)
##D qplot(mpg, wt, data=mtcars, facets = vs + am ~ . )
##D 
##D # You can also use strings, which makes it a little easier
##D # when writing functions that generate faceting specifications
##D # p + facet_grid("cut ~ .")
##D 
##D # see also ?plotmatrix for the scatterplot matrix
##D 
##D # If there isn't any data for a given combination, that panel 
##D # will be empty
##D qplot(mpg, wt, data=mtcars) + facet_grid(cyl ~ vs)
##D 
##D # If you combine a facetted dataset with a dataset that lacks those
##D # facetting variables, the data will be repeated across the missing
##D # combinations:
##D p <- qplot(mpg, wt, data=mtcars, facets = vs ~ am)
##D 
##D df <- data.frame(mpg = 22, wt = 3)
##D p + geom_point(data = df, colour="red", size = 2)
##D 
##D df2 <- data.frame(mpg = c(19, 22), wt = c(2,4), vs = c(0, 1))
##D p + geom_point(data = df2, colour="red", size = 2)
##D 
##D df2 <- data.frame(mpg = c(19, 22), wt = c(2,4), vs = c(1, 1))
##D p + geom_point(data = df2, colour="red", size = 2)
##D 
##D # You can also choose whether the scales should be constant
##D # across all panels (the default), or whether they should be allowed
##D # to vary
##D mt <- ggplot(mtcars, aes(mpg, wt, colour = factor(cyl))) + geom_point()
##D 
##D mt + facet_grid(. ~ cyl, scales = "free")
##D # If scales and space are free, then the mapping between position
##D # and values in the data will be the same across all panels
##D mt + facet_grid(. ~ cyl, scales = "free", space = "free")
##D 
##D mt + facet_grid(vs ~ am, scales = "free")
##D mt + facet_grid(vs ~ am, scales = "free_x")
##D mt + facet_grid(vs ~ am, scales = "free_y")
##D mt + facet_grid(vs ~ am, scales = "free", space="free")
##D 
##D # You may need to set your own breaks for consitent display:
##D mt + facet_grid(. ~ cyl, scales = "free_x", space="free") + 
##D   scale_x_continuous(breaks = seq(10, 36, by = 2))
##D # Adding scale limits override free scales:
##D last_plot() + xlim(10, 15)
##D 
##D # Free scales are particularly useful for categorical variables
##D qplot(cty, model, data=mpg) + 
##D   facet_grid(manufacturer ~ ., scales = "free", space = "free")
##D # particularly when you reorder factor levels
##D mpg <- within(mpg, {
##D   model <- reorder(model, cty)
##D   manufacturer <- reorder(manufacturer, cty)
##D })
##D last_plot() 
## End(Not run)


