### Name: geom_histogram
### Title: geom_histogram
### Aliases: geom_histogram GeomHistogram
### Keywords: hplot

### ** Examples
## Not run: 
##D 
##D # Simple examles
##D qplot(rating, data=movies, geom="histogram")
##D qplot(rating, data=movies, weight=votes, geom="histogram")
##D qplot(rating, data=movies, weight=votes, geom="histogram", binwidth=1)
##D qplot(rating, data=movies, weight=votes, geom="histogram", binwidth=0.1)
##D 
##D # More complex
##D m <- ggplot(movies, aes(x=rating))
##D m + geom_histogram()
##D m + geom_histogram(aes(y = ..density..)) + geom_density()
##D 
##D m + geom_histogram(binwidth = 1)
##D m + geom_histogram(binwidth = 0.5)
##D m + geom_histogram(binwidth = 0.1)
##D 
##D # Add aesthetic mappings
##D m + geom_histogram(aes(weight = votes))
##D m + geom_histogram(aes(y = ..count..))
##D m + geom_histogram(aes(fill = ..count..))
##D 
##D # Change scales
##D m + geom_histogram(aes(fill = ..count..)) + 
##D   scale_fill_gradient("Count", low = "green", high = "red")
##D 
##D # Often we don't want the height of the bar to represent the
##D # count of observations, but the sum of some other variable.
##D # For example, the following plot shows the number of movies
##D # in each rating.
##D qplot(rating, data=movies, geom="bar", binwidth = 0.1)
##D # If, however, we want to see the number of votes cast in each
##D # category, we need to weight by the votes variable
##D qplot(rating, data=movies, geom="bar", binwidth = 0.1,
##D   weight=votes, ylab = "votes")
##D 
##D m <- ggplot(movies, aes(x = votes))
##D # For transformed scales, binwidth applies to the transformed data.
##D # The bins have constant width on the transformed scale.
##D m + geom_histogram() + scale_x_log10()
##D m + geom_histogram(binwidth = 1) + scale_x_log10()
##D m + geom_histogram() + scale_x_sqrt()
##D m + geom_histogram(binwidth = 10) + scale_x_sqrt()
##D 
##D # For transformed coordinate systems, the binwidth applies to the 
##D # raw data.  The bins have constant width on the original scale.
##D 
##D # Using log scales does not work here, because the first
##D # bar is anchored at zero, and so when transformed becomes negative
##D # infinity.  This is not a problem when transforming the scales, because
##D # no observations have 0 ratings.
##D m + geom_histogram() + coord_trans(x = "log10")
##D m + geom_histogram() + coord_trans(x = "sqrt")
##D m + geom_histogram(binwidth=1000) + coord_trans(x = "sqrt")
##D   
##D # You can also transform the y axis.  Remember that the base of the bars
##D # has value 0, so log transformations are not appropriate 
##D m <- ggplot(movies, aes(x = rating))
##D m + geom_histogram(binwidth = 0.5) + scale_y_sqrt()
##D m + geom_histogram(binwidth = 0.5) + scale_y_reverse()
##D 
##D # Set aesthetics to fixed value
##D m + geom_histogram(colour = "darkgreen", fill = "white", binwidth = 0.5)
##D 
##D # Use facets
##D m <- m + geom_histogram(binwidth = 0.5)
##D m + facet_grid(Action ~ Comedy)
##D 
##D # Often more useful to use density on the y axis when facetting
##D m <- m + aes(y = ..density..)
##D m + facet_grid(Action ~ Comedy)
##D m + facet_wrap(~ mpaa)
##D 
##D # Multiple histograms on the same graph
##D # see ?position, ?position_fill, etc for more details
##D ggplot(diamonds, aes(x=price)) + geom_bar()
##D hist_cut <- ggplot(diamonds, aes(x=price, fill=cut))
##D hist_cut + geom_bar() # defaults to stacking
##D hist_cut + geom_bar(position="fill")
##D hist_cut + geom_bar(position="dodge")
## End(Not run)


