### Name: geom_path
### Title: geom_path
### Aliases: geom_path GeomPath
### Keywords: hplot

### ** Examples
## Not run: 
##D # Generate data
##D myear <- do.call(rbind, by(movies, movies$year, function(df) data.frame(year=df$year[1], mean.length = mean(df$length), mean.rating=mean(df$rating))))
##D p <- ggplot(myear, aes(x=mean.length, y=mean.rating))
##D p + geom_path()
##D 
##D # Add aesthetic mappings
##D p + geom_path(aes(size=year))
##D p + geom_path(aes(colour=year))
##D 
##D # Change scale
##D p + geom_path(aes(size=year)) + scale_size(to=c(1, 3))
##D 
##D # Set aesthetics to fixed value
##D p + geom_path(colour = "green")
##D 
##D # Use qplot instead
##D qplot(mean.length, mean.rating, data=myear, geom="path")
##D 
##D # Using economic data:
##D # How is unemployment and personal savings rate related?
##D qplot(unemploy/pop, psavert, data=economics)
##D qplot(unemploy/pop, psavert, data=economics, geom="path")
##D qplot(unemploy/pop, psavert, data=economics, geom="path", size=as.numeric(date))
##D 
##D # How is rate of unemployment and length of unemployment?
##D qplot(unemploy/pop, uempmed, data=economics)
##D qplot(unemploy/pop, uempmed, data=economics, geom="path")
##D qplot(unemploy/pop, uempmed, data=economics, geom="path") +
##D   geom_point(data=head(economics, 1), colour="red") + 
##D   geom_point(data=tail(economics, 1), colour="blue")
##D qplot(unemploy/pop, uempmed, data=economics, geom="path") +
##D   geom_text(data=head(economics, 1), label="1967", colour="blue") + 
##D   geom_text(data=tail(economics, 1), label="2007", colour="blue")
##D 
##D # Setting line type vs colour/size
##D # Line type needs to be applied to a line as a whole, so it can
##D # not be used with colour or size that vary across a line
##D 
##D x <- seq(0.01, .99, length=100)
##D df <- data.frame(x = rep(x, 2), y = c(qlogis(x), 2 * qlogis(x)), group = rep(c("a","b"), each=100))
##D p <- ggplot(df, aes(x=x, y=y, group=group))
##D 
##D # Should work
##D p + geom_line(linetype = 2)
##D p + geom_line(aes(colour = group), linetype = 2)
##D p + geom_line(aes(colour = x))
##D 
##D # Should fail
##D p + geom_line(aes(colour = x), linetype=2)
##D 
## End(Not run)


