### Name: geom_tile
### Title: geom_tile
### Aliases: geom_tile GeomTile
### Keywords: hplot

### ** Examples
## Not run: 
##D # Generate data
##D pp <- function (n,r=4) {
##D  x <- seq(-r*pi, r*pi, len=n)
##D  df <- expand.grid(x=x, y=x)
##D  df$r <- sqrt(df$x^2 + df$y^2)
##D  df$z <- cos(df$r^2)*exp(-df$r/6)
##D  df
##D }
##D p <- ggplot(pp(20), aes(x=x,y=y))
##D 
##D p + geom_tile() #pretty useless!
##D 
##D # Add aesthetic mappings
##D p + geom_tile(aes(fill=z))
##D 
##D # Change scale
##D p + geom_tile(aes(fill=z)) + scale_fill_gradient(low="green", high="red")
##D 
##D # Use qplot instead
##D qplot(x, y, data=pp(20), geom="tile", fill=z)
##D qplot(x, y, data=pp(100), geom="tile", fill=z)
##D 
##D # Missing values
##D p <- ggplot(pp(20)[sample(20*20, size=200),], aes(x=x,y=y,fill=z))
##D p + geom_tile()
##D 
##D # Input that works with image
##D image(t(volcano)[ncol(volcano):1,])
##D ggplot(melt(volcano), aes(x=X1, y=X2, fill=value)) + geom_tile()
##D 
##D # inspired by the image-density plots of Ken Knoblauch
##D cars <- ggplot(mtcars, aes(y=factor(cyl), x=mpg))
##D cars + geom_point()
##D cars + stat_bin(aes(fill=..count..), geom="tile", binwidth=3, position="identity")
##D cars + stat_bin(aes(fill=..density..), geom="tile", binwidth=3, position="identity")
##D 
##D cars + stat_density(aes(fill=..density..), geom="tile", position="identity")
##D cars + stat_density(aes(fill=..count..), geom="tile", position="identity")
##D 
##D # Another example with with unequal tile sizes
##D x.cell.boundary <- c(0, 4, 6, 8, 10, 14)
##D example <- data.frame(
##D   x = rep(c(2, 5, 7, 9, 12), 2),
##D   y = factor(rep(c(1,2), each=5)),
##D   z = rep(1:5, each=2),
##D   w = rep(diff(x.cell.boundary), 2)
##D )
##D   
##D qplot(x, y, fill=z, data=example, geom="tile")
##D qplot(x, y, fill=z, data=example, geom="tile", width=w)
##D qplot(x, y, fill=factor(z), data=example, geom="tile", width=w)
##D 
##D # You can manually set the colour of the tiles using 
##D # scale_manual
##D col <- c("darkblue", "blue", "green", "orange", "red")
##D qplot(x, y, fill=col[z], data=example, geom="tile", width=w, group=1) + scale_fill_identity(labels=letters[1:5], breaks=col)
## End(Not run)


