### Name: scale_date
### Title: scale_date
### Aliases: scale_date scale_x_date scale_y_date ScaleDate
### Keywords: hplot

### ** Examples
## Not run: 
##D # We'll start by creating some nonsense data with dates
##D df <- data.frame(
##D   date = seq(Sys.Date(), len=100, by="1 day")[sample(100, 50)],
##D   price = runif(50)
##D )
##D df <- df[order(df$date), ]
##D dt <- qplot(date, price, data=df, geom="line") + opts(aspect.ratio = 1/4)
##D 
##D # We can control the format of the labels, and the frequency of 
##D # the major and minor tickmarks.  See ?format.Date and ?seq.Date 
##D # for more details.
##D dt + scale_x_date()
##D dt + scale_x_date(format="
##D dt + scale_x_date(format="
##D dt + scale_x_date(major="months", minor="weeks", format="
##D dt + scale_x_date(major="months", minor="3 days", format="
##D dt + scale_x_date(major="years", format="
##D 
##D # The date scale will attempt to pick sensible defaults for 
##D # major and minor tick marks
##D qplot(date, price, data=df[1:10,], geom="line")
##D qplot(date, price, data=df[1:4,], geom="line")
##D 
##D df <- data.frame(
##D   date = seq(Sys.Date(), len=1000, by="1 day"),
##D   price = runif(500)
##D )
##D qplot(date, price, data=df, geom="line")
##D 
##D # A real example using economic time series data
##D qplot(date, psavert, data=economics) 
##D qplot(date, psavert, data=economics, geom="path") 
##D 
##D end <- max(economics$date)
##D last_plot() + scale_x_date(lim = c(as.Date("2000-1-1"), end))
##D last_plot() + scale_x_date(lim = c(as.Date("2005-1-1"), end))
##D last_plot() + scale_x_date(lim = c(as.Date("2006-1-1"), end))
##D 
##D # If we want to display multiple series, one for each variable
##D # it's easiest to first change the data from a "wide" to a "long"
##D # format:
##D em <- melt(economics, id = "date")
##D 
##D # Then we can group and facet by the new "variable" variable
##D qplot(date, value, data = em, geom = "line", group = variable)
##D qplot(date, value, data = em, geom = "line", group = variable) + 
##D   facet_grid(variable ~ ., scale = "free_y")
##D 
## End(Not run)


