### Name: stat_density
### Title: stat_density
### Aliases: stat_density StatDensity
### Keywords: hplot

### ** Examples
## Not run: 
##D m <- ggplot(movies, aes(x=rating))
##D m + geom_density()
##D 
##D # Adjust parameters
##D m + geom_density(kernel = "rectangular")
##D m + geom_density(kernel = "biweight") 
##D m + geom_density(kernel = "epanechnikov")
##D m + geom_density(adjust=1/5) # Very rough
##D m + geom_density(adjust=5) # Very smooth
##D 
##D # Adjust aesthetics
##D m + geom_density(aes(fill=factor(Drama)), size=2)
##D # Scale so peaks have same height:
##D m + geom_density(aes(fill=factor(Drama), y = ..scaled..), size=2)
##D 
##D m + geom_density(colour="darkgreen", size=2)
##D m + geom_density(colour="darkgreen", size=2, fill=NA)
##D m + geom_density(colour="darkgreen", size=2, fill="green")
##D 
##D # Change scales
##D (m <- ggplot(movies, aes(x=votes)) + geom_density(trim = TRUE))
##D m + scale_x_log10()
##D m + coord_trans(x="log10")
##D m + scale_x_log10() + coord_trans(x="log10")
##D 
##D # Also useful with
##D m + stat_bin()
##D 
##D # Make a volcano plot
##D ggplot(diamonds, aes(x = price)) + geom_density(aes(min = -..density.., adjust= 0.5),fill="grey50", colour=NA) + facet_grid(. ~ cut) + coord_flip() 
##D 
##D # Stacked density plots
##D # If you want to create a stacked density plot, you need to use
##D # the 'count' (density * n) variable instead of the default density
##D 
##D # Loses marginal densities
##D qplot(rating, ..density.., data=movies, geom="density", fill=mpaa, position="stack")
##D # Preserves marginal densities
##D qplot(rating, ..count.., data=movies, geom="density", fill=mpaa, position="stack")
##D 
##D # You can use position="fill" to produce a conditional density estimate
##D qplot(rating, ..count.., data=movies, geom="density", fill=mpaa, position="fill")
##D 
##D # Need to be careful with weighted data
##D m <- ggplot(movies, aes(x=rating, weight=votes))
##D m + geom_histogram(aes(y = ..count..)) + geom_density(fill=NA)
##D 
##D m <- ggplot(movies, aes(x=rating, weight=votes/sum(votes)))
##D m + geom_histogram(aes(y=..density..)) + geom_density(fill=NA, colour="black")
##D 
##D movies$decade <- round_any(movies$year, 10)
##D m <- ggplot(movies, aes(x=rating, colour=decade, group=decade)) 
##D m + geom_density(fill=NA)
##D m + geom_density(fill=NA) + aes(y = ..count..)
##D 
##D # Use qplot instead
##D qplot(length, data=movies, geom="density", weight=rating)
##D qplot(length, data=movies, geom="density", weight=rating/sum(rating))
## End(Not run)


